/*
    Font descriptor data type declaration.
    Copyright (C) 2020  Alessandro Accattini

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


 *****************************************************************************
 *
 *
 * $Header$
 *
 *
 *
 * REVISION HISTORY:
 * $Log$
 */

/**  \file fontdesc.h
     \author Alessandro Accattini
     \date 2020
     \brief Font descriptor data type declaration.
 */



#ifndef __FONTDESC_H
#define __FONTDESC_H		1


#include <stdint.h>

/***************************************************************************/
/* define pubblici */

/***************************************************************************/
/* macro pubbliche */

/***************************************************************************/
/* strutture pubbliche */

typedef struct
{
  uint8_t	*Data;			///< Font data pointer.
//  uint32_t	DataLen;		///< Font data length.
  uint8_t	First;			///< First ASCII code in the font set.
  uint8_t	Last;			///< Last ASCII code in the font set.
  uint8_t	Width;			///< Single char width (in pixel).
  uint8_t	Height;			///< Single char height (in pixel).
  uint8_t	BytePerChar;		///< Number of bytes per char.
}FontDesc_t;

/***************************************************************************/
/* costanti pubbliche */

/***************************************************************************/
/* variabili pubbliche */

/***************************************************************************/
/* funzioni pubbliche */

uint32_t FontDataSize(const FontDesc_t *Font);
  /**< \brief Returns font data array size.
       \param Font[in]   Font descriptor.
       \return           Font data array size.
   */

uint32_t FontNumOfChars(const FontDesc_t *Font);
  /**< \brief Returns the number of characters inside font.
       \param Font[in]   Font descriptor.
       \return           Number of characters.
   */

/***************************************************************************/
#endif

/* $Source$ */

