/*
    Font printing functions.
    Copyright (C) 2020 2021  Alessandro Accattini

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


 *****************************************************************************
 *
 *
 * $Header$
 *
 *
 *
 * REVISION HISTORY:
 * $Log$
 */

/**  \file print.h
     \author Alessandro Accattini
     \date 2020
     \brief Font printing functions.
 */



#ifndef __PRINT_H
#define __PRINT_H		1


#include "fontdesc.h"				// font descriptor data type
   
/***************************************************************************/
/* define pubblici */

/***************************************************************************/
/* macro pubbliche */

/***************************************************************************/
/* strutture pubbliche */

/***************************************************************************/
/* costanti pubbliche */

/***************************************************************************/
/* variabili pubbliche */

/***************************************************************************/
/* funzioni pubbliche */

void PrintCcode(const FontDesc_t *Font,const char *FontName);
  /**< \brief Prints font as C source code.
       \param Font[in]       Font to print.
       \param FontName[in]   Font name in the output file.
   */

void PrintClegacy(const FontDesc_t *Font,const char *FontName);
  /**< \brief Prints font as C source code in legacy endianness format.
       \param Font[in]       Font to print.
       \param FontName[in]   Font name in the output file.
   */

void PrintTcl(const FontDesc_t *Font,const char *FontName);
  /**< \brief Prints font as TCL code.
       \param Font[in]       Font to print.
       \param FontName[in]   Font name in the output file.
   */

void PrintAvra(const FontDesc_t *Font,const char *FontName);
  /**< \brief Prints font as Avra ASM source code.
       \param Font[in]       Font to print.
       \param FontName[in]   Font name in the output file.
   */

void PrintMicrochip(const FontDesc_t *Font,const char *FontName);
  /**< \brief Prints font in Microchip code.
       \param Font[in]       Font to print.
       \param FontName[in]   Font name in the output file.
   */

void PrintText(const FontDesc_t *Font,const char *Text,uint8_t Len);
  /**< \brief Prints on stdout using given font.
       \param Font[in]       Font to be used.
       \param Text[in]       Text to be printed.
       \param Len[in]        Text length.
   */

/***************************************************************************/
#endif

/* $Source$ */

